About Weblate
=============

Project goals
-------------

Web based translation with tight git integration supporting wide range of file
formats and makes it easy for translators to contribute.

The translations should be kept within same repository as source code and
translation process should closely follow development.

There is no plan in heavy conflict resolution as these should be primarily
handled on git side.

Project name
------------

The project is named as mixture of words web and translate.

Project website
---------------

You can find project website at <https://weblate.org/>, there is also
demonstration server at <https://demo.weblate.org/>. This documentation
can be browsed on <https://docs.weblate.org/>.

Authors
-------

This tool was written by Michal Čihař <michal@cihar.com>.
